pub trait NormalizeLast2 {
// Required method
fn normalize_last_2(&self) -> Result<Self>
where Self: Sized;
}Expand description
Normalize the distribution on the two last axis
Required Methods
fn normalize_last_2(&self) -> Result<Self>where
Self: Sized,
Implementations on Foreign Types
Sourceimpl NormalizeLast2 for Array3<f64>
Normalize the elements of an array along the two last axis
impl NormalizeLast2 for Array3<f64>
Normalize the elements of an array along the two last axis